Module internals

Module internals 

Exposes some library internals.

You’re unlikely to want to work with these objects but they are exposed for documentation primarily.

This module does not follow the same stability guarantees as the rest of the crate and is not guaranteed to be compatible between minor versions.

Structs

AutoName
Special marker to use an automatic name.
ContentPathredactions
Represents a path for a callback function.
Filtersfilters
Represents stored filters.
MetaData
Snapshot metadata information.
Redactionsredactions
Represents stored redactions.
SettingsBindDropGuard
Returned from Settings::bind_to_scope

Enums

Content
Represents variable typed content.
Redactionredactions
Replaces a value with another one.
SnapshotContents
The contents of a Snapshot