Macro insta::assert_csv_snapshot
source · macro_rules! assert_csv_snapshot { ($value:expr, @$snapshot:literal) => { ... }; ($value:expr, $(match ..)? {$($k:expr => $v:expr),*$(,)?}, @$snapshot:literal) => { ... }; ($value:expr, $(match ..)? {$($k:expr => $v:expr),*$(,)?}) => { ... }; ($name:expr, $value:expr) => { ... }; ($name:expr, $value:expr, $(match ..)? {$($k:expr => $v:expr),*$(,)?}) => { ... }; ($value:expr) => { ... }; }
Available on crate feature
csv only.Expand description
Asserts a Serialize snapshot in CSV format.
Feature: csv (disabled by default)
This works exactly like [assert_yaml_snapshot!]
but serializes in CSV format instead of
YAML.
Example:
insta::assert_csv_snapshot!(vec![1, 2, 3]);The third argument to the macro can be an object expression for redaction.
It’s in the form { selector => replacement } or match .. { selector => replacement }.
For more information about redactions refer to the redactions feature in
the guide.
The snapshot name is optional but can be provided as first argument.